@@ -28,7 +28,7 @@ import urllib
 import yaml
 
 __author__ = "handa"
-__version__ = "0.0.36"
+__version__ = "0.0.40"
 
 # DEBUG = True
 DEBUG = False
@@ -150,51 +150,7 @@ fi
 
 """
 
-noSubSpec = """
-  s.preserve_paths = "#{s.name}/Classes/**/*", "#{s.name}/Assets/**/*", "#{s.name}/Framework/**/*", "#{s.name}/Archive/**/*", "#{s.name}/Dependencies/**/*"
-
-  configuration = "Release"
-  if ENV["IS_DEBUG"] || ENV["#{s.name}_DEBUG"]
-    configuration = "Debug"
-  elsif ENV["IS_RELEASE"] || ENV["#{s.name}_Relase"]
-    configuration = "Release"
-  end
-  
-  if ENV['IS_SOURCE'] || ENV["#{s.name}_SOURCE"]
-    # 源码部分，请在这里写上必要的。
-    s.source_files = "#{s.name}/Classes/**/*.{h,m,mm,c,cpp,cc}"
-    s.public_header_files = "#{s.name}/Classes/**/*.h"
-    # 如果有自己依赖的库，请写在这里，并且把依赖的.a 或者 .framework 放到Classes 同级别的Dependencies目录下
-    # s.source_files = "#{s.name}/Classes/**/*.{h,m,mm,c,cpp,cc}", "#{s.name}/Dependencies/**/*.{h,m,mm,c,cpp,cc}"
-    # s.public_header_files = "#{s.name}/Classes/**/*.h", "#{s.name}/Dependencies/**/*.h"
-    # ...
-  elsif ENV['IS_ARCHIVE'] || ENV["#{s.name}_ARCHIVE"]
-    s.public_header_files = "#{s.name}/Archive/#{configuration}/*.h"
-    s.source_files = "#{s.name}/Archive/#{configuration}/*.h"
-    s.vendored_libraries = "#{s.name}/Archive/#{configuration}/lib#{s.name}.a"
-    # 如果源码有依赖的库，上面这一行需要换成下面的
-    # s.public_header_files = "#{s.name}/Archive/#{configuration}/*.h", "#{s.name}/Dependencies/**/*.h"
-    # s.source_files = "#{s.name}/Archive/#{configuration}/*.h", "#{s.name}/Dependencies/**/*.h"
-    # s.vendored_libraries = "#{s.name}/Archive/#{configuration}/lib#{s.name}.a","#{s.name}/Dependencies/**/*.a"
-    # s.vendored_frameworks= "#{s.name}/Dependencies/**/*.framework"
-  else
-    s.public_header_files = "#{s.name}/Framework/#{configuration}/*.h"
-    s.source_files = "#{s.name}/Framework/#{configuration}/*.h"
-    s.vendored_frameworks = "#{s.name}/Framework/#{configuration}/#{s.name}.framework"
-    # 如果源码有依赖的库，上面的一行酌情换成下面的语句
-    # s.public_header_files = "#{s.name}/Framework/#{configuration}/*.h", "#{s.name}/Dependencies/**/*.h"
-    # s.source_files = "#{s.name}/Framework/#{configuration}/*.h", "#{s.name}/Dependencies/**/*.h"
-    # s.vendored_frameworks = "#{s.name}/Framework/#{configuration}/#{s.name}.framework","#{s.name}/Dependencies/**/*.framework"
-    # s.vendored_libraries = "#{s.name}/Dependencies/**/*.a"
-  end
-  # 公共部分，比如公共资源类。framework等
-  # s.resources        = "#{s.name}/Assets/**/*.{bundle,lic,png,jpg,plist}"
-  # 或者
-  # s.resource_bundle = {
-  #   "#{s.name}" => "#{s.name}/Assets/*.{storyboard,xib,json,xcassets,png,html}"
-  # }
-
-"""
+noSubSpec = """ """
 
 
 packageBySubspec = """
@@ -212,10 +168,10 @@ packageBySubspec = """
   #subspec 的集合
   _subspecs = [_Core, _Foundation, _UIKit]
 
-  configuration = "Release"
+  configuration = "Debug"
   if ENV["IS_DEBUG"] || ENV["#{s.name}_DEBUG"]
     configuration = "Debug"
-  elsif ENV["IS_RELEASE"] || ENV["#{s.name}_Relase"]
+  elsif ENV["IS_RELEASE"] || ENV["#{s.name}_RELEASE"]
     configuration = "Release"
   end
   
@@ -792,11 +748,6 @@ def package(projectPath, podName, subSpecName, version, commitId, debug, depende
     if returnCode > 0:
         formatPrint("打包失败，请检查。", "* ")
         returnError()
-    podspecString = readFile(podspecName)
-    versionMathList = matchList(r"s.version.*= [\'\"](\d+(\.\d+){1,3})[\'\"]", podspecString)[0]
-    if not versionMathList:
-        formatPrint("找不到版本信息，请检查podspec里的 s.version 字段")
-    version = str(versionMathList[0])
     formatPrint(version)
     buildPath = podName + subSpecName + "-" + version
     binaryFilePath = buildPath + "/ios/" + prefixString + podName + subSpecName + suffixString
@@ -927,7 +878,7 @@ def createPodSpecContent(podName, subspecName, version, commitId, dependencyJSON
                 lineStr = lineStr.replace(originLine, replaceVersion)
         elif tmpLineStr.startswith("s.source") and tmpLineStr.find(":git") > -1:
             originSourceLine = tmpLineStr
-            tmpLineStr = tmpLineStr.replace("git.lianjia.com", "gerrit.lianjia.com")
+            tmpLineStr = tmpLineStr.replace("git.lianjia.com", "gerrit.lianjia.com").replace("http://gerrit.lianjia.com", "ssh://git-mobileadmin@gerrit.lianjia.com:29418")
             sourceStr = str(tmpLineStr).strip("\n").strip("").split(",")[0].strip("}")
             replaceSource = ""
             if commitId:
@@ -1224,7 +1175,7 @@ def autoPackage(projectPath, podName, branch, version, subPackage=False, commitI
             if returnCode > 0:
                 formatPrint("不能获取当前分支的最新commit", " *")
                 returnError()
-            commitId = newCommitId
+            commitId = str(newCommitId).strip("\n")
     formatPrint("正在切换到分支" + branch, "- ")
     excommandUntilDone("git checkout " + branch)
     # 检查是否符合规范
@@ -1440,6 +1391,7 @@ def getRepoDict():
     if returnCode > 0:
         formatPrint("pod repo list 失败", " *")
         returnError()
+    content = matchList("lianjia-mobile_.*", content)[0]
     contentLines = content.split("\n")
     yamlContent = ""
     for line in contentLines:
